@@ -45,7 +45,7 @@ end
 
 class Rake::RemoteTask < Rake::Task
 
-  VERSION = "2.2.2"
+  VERSION = "2.3.0"
 
   @@current_roles = []
 
@@ -446,13 +446,15 @@ class Rake::RemoteTask < Rake::Task
     Rake::RemoteTask.default_env[name] = Rake::RemoteTask.env[name] =
       default_block || value
 
-    if Object.public_instance_methods.include? name.to_sym then
+    if Object.private_instance_methods.include? name.to_sym then
       Object.send :alias_method, :"old_#{name}", name
     end
 
     Object.send :define_method, name do
       Rake::RemoteTask.fetch name
     end
+
+    Object.send :private, name
   end
 
   ##
